@@ -76,7 +76,7 @@ class RecordingJobAdmin(admin.ModelAdmin):
 
     list_per_page = 200
 
-    search_fields = ['status']
+    search_fields = ['status','recordingjobmetadata__value' ]
 
     exclude = ["recording_source"]
     readonly_fields = [
